import { BackgroundImage } from '@rneui/base';
import { FlatList, StyleSheet, Text, View, Image, TouchableOpacity } from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import MapView from 'react-native-maps';
import PROVIDER_OPENSTREETMAP, { Marker } from 'react-native-maps';
import React from 'react';

export default function Lap() {

    return (
        <SafeAreaView style={styles.container}>
            <View style={styles.container}>
                {/* Header */}
                <View style={styles.topbar}>
                    <View>
                        <TouchableOpacity style={styles.accountContainerButton}>
                            <View style={styles.ImageContainer}>
                                <Image source={require('../assets/images/pfp.png')} style={styles.accountImage} />
                            </View>
                            <Text style={styles.accountName}>Mr X</Text>
                        </TouchableOpacity>
                    </View>
                    <View style={styles.topbarRight}>
                        <View style={styles.iconContainer}>
                            <Image source={require('../assets/images/settings.png')} style={styles.accountSettings} />
                        </View>
                        <TouchableOpacity style={styles.accountContainerButton}>
                            <View style={styles.ImageContainer}>
                                <Image source={require('../assets/images/rdash.png')} style={styles.accountImage} />
                            </View>
                        </TouchableOpacity>
                    </View>
                </View>

                {/* Body */}
                <View style={styles.container}>
                    <BackgroundImage source={require('../assets/images/rdash.png')} resizeMode="contain" style={styles.backgroundImage}>

                        <View style={styles.top_lap}>
                            <TouchableOpacity style={styles.LapBrowserButton} >
                                <View>
                                    <Text style={styles.button_text} >Previous lap</Text>
                                </View>
                            </TouchableOpacity>

                            <Text style={styles.text_title}>Lap X</Text>

                            <TouchableOpacity style={styles.LapBrowserButton}>
                                <View>
                                    <Text style={styles.button_text} >Next lap</Text>
                                </View>
                            </TouchableOpacity>

                        </View>

                        <View style={styles.container}>
                            <MapView
                                style={styles.map}
                                region={{
                                    latitude: 46.863415273862,
                                    longitude: 3.161789595537,
                                    latitudeDelta: 0.001,
                                    longitudeDelta: 0.01,
                                }}
                            >
                                <Marker
                                    coordinate={{
                                        latitude: 46.863415273862,
                                        longitude: 3.161789595537
                                    }}
                                    title="Marker Title"
                                    description="Marker Description"
                                />
                                <Marker
                                    coordinate={{
                                        latitude: 46.861927477535,
                                        longitude: 3.160353322067
                                    }}
                                    title="Marker Title"
                                    description="Marker Description"
                                />
                                <Marker
                                    coordinate={{
                                        latitude: 46.859745172448,
                                        longitude: 3.164897426081
                                    }}
                                    title="Marker Title"
                                    description="Marker Description"
                                />
                            </MapView>

                            <Text style={styles.textStyle} >Time: 1 30,62 seconds</Text>

                            <View style={styles.infoContainer}>
                                <Text style={styles.textStyle} >Average Speed: {"\n"} 102 km/h</Text>
                                <Text style={styles.textStyle} >G: {"\n"} 0.001 G</Text>


                            </View>
                            <Text style={styles.textStyle} ></Text>

                        </View>
                    </BackgroundImage>
                </View>

            </View>
        </SafeAreaView>
    );
}

// TROUBLE SHOOTING BORDER :
//borderColor:'red',
//borderWidth:3,

const styles = StyleSheet.create({
    card: {
        flexDirection: 'column',
        height: "80%",
        width: "80%",
        backgroundColor: "#fff",
        borderRadius: 15,
        padding: 10,
        elevation: 10,
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 3 },
        shadowOpacity: 0.5,
        shadowRadius: 5,
    },
    infoContainer: {
        margin: 3,
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-around',
    },
    map: {
        height: "40%",
    },
    top_lap: {
        height: "8%",
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    backgroundImage: {
        flex: 1,
        width: '100%',
    },

    container: {
        flex: 1,
    },

    accountSettings: {
        width: '100%',
        height: '100%',
    },

    accountContainerButton: {
        flexDirection: 'row',
        alignItems: 'center',
    },

    LapBrowserButton: {
        width: "30%",
        margin: 5,
        alignContent: 'center',
        justifyContent: 'center',
        borderRadius: 10,
        backgroundColor: '#BF181F',
    },
    button_text: {
        textAlign: 'center',
        color: '#fff',
        fontSize: 20,
    },

    ImageContainer: {
        backgroundColor: '#fff',
        borderRadius: 50,
        width: 40,
        height: 40,
        overflow: 'hidden',
        marginRight: 10,

    },
    accountImage: {
        width: '100%',
        height: '100%',
    },
    topbar: {
        backgroundColor: '#BF181D',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-between',
        paddingHorizontal: 20,
        height: "8%",
    },
    accountName: {
        color: '#fff',
        fontSize: 20,
    },
    topbarRight: {
        flex: 1,
        alignItems: 'flex-end',
    },
    textStyle: {
        margin: 3,
        fontSize: 20,
        backgroundColor: '#BF181D',
        color: 'white',
        padding: "2%",
        borderRadius: 5,

    },
    text_title: {
        fontWeight: 'bold',
        fontSize: 30,
        textAlign: 'center',
        padding: 10,
        textShadowColor: '#fff',
        textShadowOffset: { width: 0, height: 0 },
        textShadowRadius: 10,
    },
    iconContainer: {
        position: 'absolute',
        bottom: 0,
        right: 0,
        backgroundColor: 'transparent',
        width: 24,
        height: 24,
    },
});